@@ -27,6 +27,7 @@ class TaukContext:
         self._setup_error_logger()
         self._exec_file = os.path.join(self.exec_dir, 'exec.run')
         self.api = TaukApi(tauk_config.api_token, tauk_config.project_id, tauk_config.multiprocess_run)
+        self._project_root_dir = tauk_config.project_root_dir
 
         # Initialize Tauk Assistant
         self.assistant: TaukAssistant | None = None
@@ -43,6 +44,10 @@ class TaukContext:
 
         self.run_id = self._init_run()
 
+    @property
+    def project_root_dir(self):
+        return self._project_root_dir
+
     def _setup_exec_dir(self, multiprocess_run):
         self.exec_dir = self._get_exec_dir(multiprocess_run)
         if not os.path.exists(self.exec_dir):
@@ -58,7 +63,7 @@ class TaukContext:
         self.error_log = os.path.join(self.exec_dir, 'tauk-webdriver-error.log')
         error_file_handler = logging.FileHandler(filename=self.error_log)
         error_file_handler.setLevel(logging.WARNING)
-        formatter = CustomJsonFormatter('%(timestamp)s %(process)d %(threadName)s %(levelname)s %(message)s')
+        formatter = CustomJsonFormatter('%(timestamp)s %(process)d %(threadName)s %(message)s', tauk_context=self)
         error_file_handler.setFormatter(formatter)
         logger.addHandler(error_file_handler)
 
